==> net.bluemind.p2.platform-4.9.3879.zip: netbluemind/core/container/api/Ack.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Ack :
    def __init__( self):
        self.version = None
        pass

class __AckSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = Ack()
        
        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        versionValue = value['version']
        instance.version = serder.LONG.parse(versionValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        versionValue = value.version
        instance["version"] = serder.LONG.encode(versionValue)
        return instance

==> net.bluemind.p2.platform-5.5.3112.zip: netbluemind/core/container/api/Ack.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Ack :
    def __init__( self):
        self.version = None
        self.timestamp = None
        pass

class __AckSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = Ack()
        
        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        versionValue = value['version']
        instance.version = serder.LONG.parse(versionValue)
        timestampValue = value['timestamp']
        instance.timestamp = serder.DATE.parse(timestampValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        versionValue = value.version
        instance["version"] = serder.LONG.encode(versionValue)
        timestampValue = value.timestamp
        instance["timestamp"] = serder.DATE.encode(timestampValue)
        return instance
